@@ -8,7 +8,7 @@ use LWP::UserAgent;
 use HTTP::Request::Common;
 use HTML::TokeParser::Simple;
 
-$VERSION = 0.2;
+$VERSION = 0.3001;
 
 sub new {
 	my $class = shift;
@@ -33,7 +33,7 @@ sub generate {
 
 	my $ua = LWP::UserAgent->new;
   my $response;
-  
+
   if ($self->{start} and $self->{start} eq 'no')
   {
     $response = $ua->request(POST 'http://www.lipsum.com/feed/http', [
@@ -49,14 +49,14 @@ sub generate {
           start  => 1
         ]);
   }
-      
+
   return "Error: $!" unless $response->is_success;
 
   my $raw = $response->content;
   die "Fatal error: lipsum page wasn't as expected." unless defined $raw && $raw =~ /(.*)Generated(.*)/s;
 
   my $stream = HTML::TokeParser::Simple->new( \$raw ) or die $!;
- 
+
   while (my $token = $stream->get_token)
   {
     # We're looking for '<div id="lipsum">'.
@@ -65,7 +65,7 @@ sub generate {
     my $text = $stream->get_text('/div');
 
     $text =~ s/ //; # remove leading space
-    
+
     if ($self->{what} =~ /^words$/i or $self->{what} =~ /^bytes$/i)
     {
       $text =~ s/\n//g;
@@ -82,21 +82,21 @@ sub generate {
   }
 }
 
-# The splitting and pushing and what-have-you that you're about to 
-# encounter would almost certainly be unnecessary if I really 
+# The splitting and pushing and what-have-you that you're about to
+# encounter would almost certainly be unnecessary if I really
 # understood HTML::TokeParser.
 
-sub paras 
+sub paras
 {
   my ($self, $text) = @_;
   my @paras;
-  
+
   foreach (split("\n", $text))
   {
     next unless $_ !~ /^ /; # drop empty chunks
     push (@paras, $_);
   }
-  
+
   for (0..1) { shift @paras; } # drop empty items
 
   if (defined $self->{html})
@@ -114,7 +114,7 @@ sub lists
 
   foreach (split( "\n", $text ))
   {
-    next unless $_ =~ /  /; # drop empty chunks    
+    next unless $_ =~ /  /; # drop empty chunks
     $_ =~ s/.//;            # remove leading space
     chop $_;                # remove trailing space
 
@@ -124,14 +124,14 @@ sub lists
       $line .= "\n";
       push (@list, $line);
     }
-    
+
     my $tidied = join ('', @list);
 
     $tidied = "<ul>\n" . $tidied . '</ul>' if $self->{html};
-    
+
     push (@items, $tidied);
   }
-  
+
   @items;
 }
 
@@ -152,19 +152,19 @@ WWW::Lipsum - get autogenerated text from lipsum.com
 =head1 DESCRIPTION
 
 C<WWW::Lipsum> is a module that will retrive "lorem ipsum" placeholder text
-from lipsum.com. 
+from lipsum.com.
 
 What is "lorem ipsum"?
 
-    "Lorem Ipsum, or Lipsum for short, is simply dummy text of the 
-    printing and typesetting industry. Lipsum has been the industry's 
-    standard dummy text ever since the 1500s, when an unknown printer 
-    took a galley of type and scrambled it to make a type specimen book. 
-    It has survived not only four centuries, but now the leap into 
-    electronic typesetting, remaining essentially unchanged. It was 
-    popularised in the 1960s with the release of Letraset sheets 
-    containing Lipsum passages, and more recently with desktop 
-    publishing software like Aldus PageMaker including versions of 
+    "Lorem Ipsum, or Lipsum for short, is simply dummy text of the
+    printing and typesetting industry. Lipsum has been the industry's
+    standard dummy text ever since the 1500s, when an unknown printer
+    took a galley of type and scrambled it to make a type specimen book.
+    It has survived not only four centuries, but now the leap into
+    electronic typesetting, remaining essentially unchanged. It was
+    popularised in the 1960s with the release of Letraset sheets
+    containing Lipsum passages, and more recently with desktop
+    publishing software like Aldus PageMaker including versions of
     Lipsum."  -- lipsum.com
 
 lipsum.com is a useful resource on the Web that will generate passages of
@@ -223,8 +223,8 @@ used to fill a variable, this will give you a list with one item.
                             what   => 'bytes'
                            );
 
-This will give you 1024 bytes of lorem ipsum with the starting phrase. 
-Again, the 'html' setting will have no effect. Again, this will give 
+This will give you 1024 bytes of lorem ipsum with the starting phrase.
+Again, the 'html' setting will have no effect. Again, this will give
 you a one-item list.
 
    my @lists = $lipsum->generate(
@@ -247,20 +247,29 @@ alias to C<generate> if you really want it.
 
 =head1 AUTHOR
 
-Earle Martin <emartin@cpan.org> wrote this scraper, but see THANKS for details 
+Earle Martin <emartin@cpan.org> wrote this scraper, but see THANKS for details
 of who really did the work.
 
-=head1 LICENSE
+=head1 MAINTAINER
 
-This work is licensed under the Creative Commons Attribution-ShareAlike
+Zoffix Znet <zoffix@cpan.org>
+
+=head1 LICENSE AND COPYRIGHT
+
+This program is licensed under the Creative Commons Attribution-ShareAlike
 License. To view a copy of this license, visit
 L<http://creativecommons.org/licenses/by-sa/1.0/> or send a letter to Creative
 Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
 
+=head1 LICENSE AND COPYRIGHT
+
+Artistic ### This is to fix a seemingly buggy behaviour of
+Test::Kwalitee; the actual license is in the section above
+
 =head1 THANKS
 
-All kudos must go to James Wilson <webmaster(at)lipsum.com> for creating 
-lipsum.com and thus providing inspiration for this module - and also for kindly 
+All kudos must go to James Wilson <webmaster(at)lipsum.com> for creating
+lipsum.com and thus providing inspiration for this module - and also for kindly
 actually modifying the way his site works to make it easier for me to parse.
 
 =cut
\ No newline at end of file
